@@ -27,6 +27,8 @@
 #include <sys/mman.h>
 #endif
 
+#include "EbAppOutputivf.h"
+
 /***************************************
  * Macros
  ***************************************/
@@ -158,7 +160,7 @@ static void release_memory_mapped_file(EbConfig *config, uint8_t is_16bit,
                                        EbBufferHeaderType *header_ptr) {
     const uint32_t input_padded_width  = config->input_padded_width;
     const uint32_t input_padded_height = config->input_padded_height;
-    uint64_t luma_read_size = (uint64_t)input_padded_width * input_padded_height
+    uint64_t       luma_read_size      = (uint64_t)input_padded_width * input_padded_height
         << (config->config.compressed_ten_bit_format ? 0 : is_16bit);
     const uint8_t  color_format = config->config.encoder_color_format;
     EbSvtIOFormat *input_ptr    = (EbSvtIOFormat *)header_ptr->p_buffer;
@@ -179,8 +181,8 @@ static void release_memory_mapped_file(EbConfig *config, uint8_t is_16bit,
 void read_input_frames(EbConfig *config, uint8_t is_16bit, EbBufferHeaderType *header_ptr) {
     const uint32_t input_padded_width  = config->input_padded_width;
     const uint32_t input_padded_height = config->input_padded_height;
-    FILE *         input_file = config->input_file;
-    EbSvtIOFormat *input_ptr  = (EbSvtIOFormat *)header_ptr->p_buffer;
+    FILE          *input_file          = config->input_file;
+    EbSvtIOFormat *input_ptr           = (EbSvtIOFormat *)header_ptr->p_buffer;
 
     const uint8_t color_format  = config->config.encoder_color_format;
     const uint8_t subsampling_x = (color_format == EB_YUV444 ? 1 : 2) - 1;
@@ -198,19 +200,19 @@ void read_input_frames(EbConfig *config, uint8_t is_16bit, EbBufferHeaderType *h
             header_ptr->n_filled_len = 0;
 
             if (config->mmap.enable) {
-                if (config->y4m_input == EB_TRUE && config->processed_frame_count == 0) {
+                if (config->y4m_input == TRUE && config->processed_frame_count == 0) {
                     read_and_compute_y4m_frame_delimiter(
                         config->input_file, config->error_log_file, &config->mmap.y4m_frm_hdr);
                 }
             } else {
                 /* if input is a y4m file, read next line which contains "FRAME" */
-                if (config->y4m_input == EB_TRUE)
+                if (config->y4m_input == TRUE)
                     read_y4m_frame_delimiter(config->input_file, config->error_log_file);
             }
             uint64_t luma_read_size = (uint64_t)input_padded_width * input_padded_height
                 << is_16bit;
             uint32_t chroma_read_size = ((uint32_t)luma_read_size >> (3 - color_format));
-            uint8_t *eb_input_ptr = input_ptr->luma;
+            uint8_t *eb_input_ptr     = input_ptr->luma;
             if (!config->y4m_input && config->processed_frame_count == 0 &&
                 (config->input_file == stdin || config->input_file_is_fifo)) {
                 /* 9 bytes were already buffered during the the YUV4MPEG2 header probe */
@@ -263,7 +265,7 @@ void read_input_frames(EbConfig *config, uint8_t is_16bit, EbBufferHeaderType *h
                     header_ptr->n_filled_len += (input_ptr->cr ? chroma_read_size : 0);
                 } else if (!config->input_file_is_fifo) {
                     fseek(input_file, 0, SEEK_SET);
-                    if (config->y4m_input == EB_TRUE) {
+                    if (config->y4m_input == TRUE) {
                         read_and_skip_y4m_header(config->input_file);
                         read_y4m_frame_delimiter(config->input_file, config->error_log_file);
                     }
@@ -282,7 +284,7 @@ void read_input_frames(EbConfig *config, uint8_t is_16bit, EbBufferHeaderType *h
             const uint32_t chroma_read_size      = luma_read_size >> (3 - color_format);
             const uint32_t nbit_luma_read_size   = (input_padded_width / 4) * input_padded_height;
             const uint32_t nbit_chroma_read_size = nbit_luma_read_size >> (3 - color_format);
-            read_size = luma_read_size + nbit_luma_read_size +
+            read_size                            = luma_read_size + nbit_luma_read_size +
                 2 * (chroma_read_size + nbit_chroma_read_size);
             // Fill the buffer with a complete frame
             header_ptr->n_filled_len = 0;
@@ -479,7 +481,7 @@ static long get_next_qp_from_qp_file(FILE *const qp_file, int *const qp_read_fro
     return qp;
 }
 
-static unsigned char send_qp_on_the_fly(FILE *const qp_file, EbBool *use_qp_file) {
+static unsigned char send_qp_on_the_fly(FILE *const qp_file, Bool *use_qp_file) {
     long tmp_qp            = 0;
     int  qp_read_from_file = 0;
 
@@ -488,7 +490,7 @@ static unsigned char send_qp_on_the_fly(FILE *const qp_file, EbBool *use_qp_file
         tmp_qp = get_next_qp_from_qp_file(qp_file, &qp_read_from_file);
 
     if (tmp_qp == -1) {
-        *use_qp_file = EB_FALSE;
+        *use_qp_file = FALSE;
         fprintf(stderr, "\nWarning: QP File did not contain any valid QPs");
     }
     return (unsigned)CLIP3(0, 63, tmp_qp);
@@ -527,23 +529,23 @@ static void injector(uint64_t processed_frame_count, uint32_t injector_frame_rat
 // them into the input buffer
 /************************************/
 void process_input_buffer(EncChannel *channel) {
-    EbConfig *          config           = channel->config;
-    EbAppContext *      app_call_back    = channel->app_callback;
+    EbConfig           *config           = channel->config;
+    EbAppContext       *app_call_back    = channel->app_callback;
     uint8_t             is_16bit         = (uint8_t)(config->config.encoder_bit_depth > 8);
     EbBufferHeaderType *header_ptr       = app_call_back->input_buffer_pool;
-    EbComponentType *   component_handle = (EbComponentType *)app_call_back->svt_encoder_handle;
+    EbComponentType    *component_handle = (EbComponentType *)app_call_back->svt_encoder_handle;
 
     AppExitConditionType return_value = APP_ExitConditionNone;
 
-    const uint8_t color_format = config->config.encoder_color_format;
-    const int64_t input_padded_width = config->input_padded_width;
-    const int64_t input_padded_height = config->input_padded_height;
+    const uint8_t color_format         = config->config.encoder_color_format;
+    const int64_t input_padded_width   = config->input_padded_width;
+    const int64_t input_padded_height  = config->input_padded_height;
     const int64_t frames_to_be_encoded = config->frames_to_be_encoded;
     int64_t       total_bytes_to_process_count;
     int64_t       remaining_byte_count;
-    uint32_t      compressed10bit_frame_size = (uint32_t)(
-        (input_padded_width * input_padded_height) +
-        2 * ((input_padded_width * input_padded_width) >> (3 - color_format)));
+    uint32_t      compressed10bit_frame_size =
+        (uint32_t)((input_padded_width * input_padded_height) +
+                   2 * ((input_padded_width * input_padded_width) >> (3 - color_format)));
     compressed10bit_frame_size += compressed10bit_frame_size / 4;
 
     if (channel->exit_cond_input != APP_ExitConditionNone)
@@ -562,7 +564,7 @@ void process_input_buffer(EncChannel *channel) {
         : total_bytes_to_process_count - (int64_t)config->processed_byte_count;
 
     // If there are bytes left to encode, configure the header
-    if (remaining_byte_count != 0 && config->stop_encoder == EB_FALSE) {
+    if (remaining_byte_count != 0 && config->stop_encoder == FALSE) {
         read_input_frames(config, is_16bit, header_ptr);
         if (header_ptr->n_filled_len) {
             // Update the context parameters
@@ -577,7 +579,7 @@ void process_input_buffer(EncChannel *channel) {
                 header_ptr->qp = send_qp_on_the_fly(config->qp_file, &config->config.use_qp_file);
 
             if (keep_running == 0 && !config->stop_encoder)
-                config->stop_encoder = EB_TRUE;
+                config->stop_encoder = TRUE;
             // Fill in Buffers Header control data
             header_ptr->pts      = config->processed_frame_count - 1;
             header_ptr->pic_type = EB_AV1_INVALID_PICTURE;
@@ -613,77 +615,11 @@ void process_input_buffer(EncChannel *channel) {
 #define LONG_ENCODE_FRAME_ENCODE 4000
 #define SPEED_MEASUREMENT_INTERVAL 2000
 #define START_STEADY_STATE 1000
-#define AV1_FOURCC 0x31305641 // used for ivf header
-#define IVF_STREAM_HEADER_SIZE 32
-#define IVF_FRAME_HEADER_SIZE 12
 #define OBU_FRAME_HEADER_SIZE 3
 #define TD_SIZE 2
-static __inline void mem_put_le32(void *vmem, int32_t val) {
-    uint8_t *mem = (uint8_t *)vmem;
 
-    mem[0] = (uint8_t)((val >> 0) & 0xff);
-    mem[1] = (uint8_t)((val >> 8) & 0xff);
-    mem[2] = (uint8_t)((val >> 16) & 0xff);
-    mem[3] = (uint8_t)((val >> 24) & 0xff);
-}
 #define MEM_VALUE_T_SZ_BITS (sizeof(MEM_VALUE_T) << 3)
 
-static __inline void mem_put_le16(void *vmem, int32_t val) {
-    uint8_t *mem = (uint8_t *)vmem;
-
-    mem[0] = (uint8_t)((val >> 0) & 0xff);
-    mem[1] = (uint8_t)((val >> 8) & 0xff);
-}
-
-static void write_ivf_stream_header(EbConfig *config) {
-    char header[IVF_STREAM_HEADER_SIZE];
-    header[0] = 'D';
-    header[1] = 'K';
-    header[2] = 'I';
-    header[3] = 'F';
-    mem_put_le16(header + 4, 0); // version
-    mem_put_le16(header + 6, 32); // header size
-    mem_put_le32(header + 8, AV1_FOURCC); // fourcc
-    mem_put_le16(header + 12, config->input_padded_width); // width
-    mem_put_le16(header + 14, config->input_padded_height); // height
-    if (config->config.frame_rate_denominator != 0 && config->config.frame_rate_numerator != 0) {
-        mem_put_le32(header + 16, config->config.frame_rate_numerator); // rate
-        mem_put_le32(header + 20, config->config.frame_rate_denominator); // scale
-            //mem_put_le32(header + 16, config->frame_rate_denominator);  // rate
-            //mem_put_le32(header + 20, config->frame_rate_numerator);  // scale
-    } else {
-        mem_put_le32(header + 16, (config->config.frame_rate >> 16) * 1000); // rate
-        mem_put_le32(header + 20, 1000); // scale
-            //mem_put_le32(header + 16, config->frame_rate_denominator);  // rate
-            //mem_put_le32(header + 20, config->frame_rate_numerator);  // scale
-    }
-    mem_put_le32(header + 24, 0); // length
-    mem_put_le32(header + 28, 0); // unused
-    //config->performance_context.byte_count += 32;
-    if (config->bitstream_file)
-        fwrite(header, 1, IVF_STREAM_HEADER_SIZE, config->bitstream_file);
-
-    return;
-}
-
-static void write_ivf_frame_header(EbConfig *config, uint32_t byte_count) {
-    char    header[IVF_FRAME_HEADER_SIZE];
-    int32_t write_location = 0;
-
-    mem_put_le32(&header[write_location], (int32_t)byte_count);
-    write_location = write_location + 4;
-    mem_put_le32(&header[write_location], (int32_t)((config->ivf_count) & 0xFFFFFFFF));
-    write_location = write_location + 4;
-    mem_put_le32(&header[write_location], (int32_t)((config->ivf_count) >> 32));
-
-    config->byte_count_since_ivf = (byte_count);
-
-    config->ivf_count++;
-    fflush(stdout);
-
-    if (config->bitstream_file)
-        fwrite(header, 1, IVF_FRAME_HEADER_SIZE, config->bitstream_file);
-}
 double get_psnr(double sse, double max) {
     double psnr;
     if (sse == 0)
@@ -764,11 +700,11 @@ void process_output_statistics_buffer(EbBufferHeaderType *header_ptr, EbConfig *
 }
 
 void process_output_stream_buffer(EncChannel *channel, EncApp *enc_app, int32_t *frame_count) {
-    EbConfig *           config        = channel->config;
-    EbAppContext *       app_call_back = channel->app_callback;
-    AppPortActiveType *  port_state    = &app_call_back->output_stream_port_active;
-    EbBufferHeaderType * header_ptr;
-    EbComponentType *    component_handle = (EbComponentType *)app_call_back->svt_encoder_handle;
+    EbConfig            *config        = channel->config;
+    EbAppContext        *app_call_back = channel->app_callback;
+    AppPortActiveType   *port_state    = &app_call_back->output_stream_port_active;
+    EbBufferHeaderType  *header_ptr;
+    EbComponentType     *component_handle = (EbComponentType *)app_call_back->svt_encoder_handle;
     AppExitConditionType return_value     = APP_ExitConditionNone;
     // Per channel variables
     FILE *stream_file = config->bitstream_file;
@@ -828,7 +764,10 @@ void process_output_stream_buffer(EncChannel *channel, EncApp *enc_app, int32_t
             if (stream_file) {
                 if (config->performance_context.frame_count == 1 &&
                     !(flags & EB_BUFFERFLAG_IS_ALT_REF)) {
-                    write_ivf_stream_header(config);
+                    write_ivf_stream_header(config,
+                                            config->frames_to_be_encoded == -1
+                                                ? 0
+                                                : (int32_t)config->frames_to_be_encoded);
                 }
                 write_ivf_frame_header(config, header_ptr->n_filled_len);
                 fwrite(header_ptr->p_buffer, 1, header_ptr->n_filled_len, stream_file);
@@ -871,7 +810,6 @@ void process_output_stream_buffer(EncChannel *channel, EncApp *enc_app, int32_t
                     }
                 }
                 if (config->config.pass == ENC_SECOND_PASS) {
-
                     if (config->output_stat_file && config->config.rc_stats_buffer.buf) {
                         fwrite(config->config.rc_stats_buffer.buf,
                                1,
@@ -882,14 +820,8 @@ void process_output_stream_buffer(EncChannel *channel, EncApp *enc_app, int32_t
             }
             ++*frame_count;
             const double fps = (double)*frame_count / config->performance_context.total_encode_time;
-            const double frame_rate = config->config.frame_rate_numerator &&
-                    config->config.frame_rate_denominator
-                ? (double)config->config.frame_rate_numerator /
-                    (double)config->config.frame_rate_denominator
-                : config->config.frame_rate > 1000
-                // Correct for 16-bit fixed-point fractional precision
-                ? (double)config->config.frame_rate / (1 << 16)
-                : (double)config->config.frame_rate;
+            const double frame_rate = (double)config->config.frame_rate_numerator /
+                (double)config->config.frame_rate_denominator;
             switch (config->progress) {
             case 0: break;
             case 1:
@@ -924,11 +856,11 @@ void process_output_stream_buffer(EncChannel *channel, EncApp *enc_app, int32_t
     channel->exit_cond_output = return_value;
 }
 void process_output_recon_buffer(EncChannel *channel) {
-    EbConfig *          config        = channel->config;
-    EbAppContext *      app_call_back = channel->app_callback;
+    EbConfig           *config        = channel->config;
+    EbAppContext       *app_call_back = channel->app_callback;
     EbBufferHeaderType *header_ptr =
         app_call_back->recon_buffer; // needs to change for buffered input
-    EbComponentType *    component_handle = (EbComponentType *)app_call_back->svt_encoder_handle;
+    EbComponentType     *component_handle = (EbComponentType *)app_call_back->svt_encoder_handle;
     AppExitConditionType return_value     = APP_ExitConditionNone;
     int32_t              fseek_return_val;
     if (channel->exit_cond_recon != APP_ExitConditionNone) {
